<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../batchprocessing.cpp" line="43"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="44"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>O núcleo actual não suporta o algoritmo de compressão seleccionado; editar o ficheiro de configuração e seleccionar outro algoritmo.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>MX Snapshot</source>
        <translation>MX-Capturas ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Snapshot location:</source>
        <translation>Localização da captura:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;O MX-Capturas ISO é um utilitário que cria imagens carregáveis (de arranque) do sistema, que podem ser usadas para guardar ou para distribuir. Permite trabalhar com aplicações pouco pesadas enquanto está em execução.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Espaço usado nas partições / (raiz ou root) e /home :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Snapshot name:</source>
        <translation>Nome da captura:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>Select a different snapshot directory</source>
        <translation>Escolher outro directório de capturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Optional customization</source>
        <translation>Personalização opcional</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>Boot options:</source>
        <translation>Opções de arranque:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Release date:</source>
        <translation>Data de lançamento:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Project name:</source>
        <translation>Nome do projeto:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Release version:</source>
        <translation>Versão de lançamento:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Release codename:</source>
        <translation>Nome de código do lançamento:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Location and ISO name</source>
        <translation>Local e nome da ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <location filename="../mainwindow.ui" line="370"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>É possível excluir alguns directórios; podem ser marcadas escolhas comuns, abaixo, ou clicado o botão para editar directamente o ficheiro /etc/mx-snapshot-exclude.list.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>All of the above</source>
        <translation>Todos os acima</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Downloads</source>
        <translation>Transferências</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Desktop</source>
        <translation>Área de trabalho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>exclude network configurations</source>
        <translation>excluir configurações de rede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>Networks</source>
        <translation>Redes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Esta opção restabelecerá as senhas de &amp;quot;demo&amp;quot; e &amp;quot;root&amp;quot; para as senhas predefinidas do MX e não copiará quaisquer contas pessoais criadas.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="538"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Restablecendo as contas/senhas pré-definidas root e demo (para distribuição a outros)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="515"/>
        <source>Type of snapshot:</source>
        <translation>Tipo de captura:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="505"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Preservando as contas criadas (para segurança pessoal)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>Edit Exclusion File</source>
        <translation>Editar o ficheiro de exclusão</translation>
    </message>
    <message>
        <source>lz4</source>
        <translation type="vanished">lz4</translation>
    </message>
    <message>
        <source>lzo</source>
        <translation type="vanished">lzo</translation>
    </message>
    <message>
        <source>gzip</source>
        <translation type="vanished">gzip</translation>
    </message>
    <message>
        <source>xz</source>
        <translation type="vanished">xz</translation>
    </message>
    <message>
        <source>zstd</source>
        <translation type="vanished">zstd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Options:</source>
        <translation>Opções: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>ISO compression scheme:</source>
        <translation>Esquema de compressão ISO:</translation>
    </message>
    <message>
        <source>Calculate checksums</source>
        <translation type="vanished">Calcular as somas de controlo (checksums)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="866"/>
        <source>Display help </source>
        <translation>Mostrar ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="869"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="876"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="733"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>sha512</source>
        <translation>sha512</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="604"/>
        <source>md5</source>
        <translation>md5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="611"/>
        <source>Calculate checksums:</source>
        <translation>Calcular as somas de controlo (checksums):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="759"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>fastest, worst compression</source>
        <translation>mais rápida, a pior compressão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>fast, worse compression</source>
        <translation>rápida, pior compressão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>slow, better compression</source>
        <translation>lenta, melhor compressão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>best compromise</source>
        <translation>melhor opção</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <source>slowest, best compression</source>
        <translation>mais lenta, a melhor compressão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Espaço livre em %1, onde a pasta de capturas está colocada:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>O espaço livre deve ser suficiente para conter os dados comprimidos de /  e de /home

      Se necessário, poderá ser libertado mais espaço na pasta removendo
      capturas anteriores e cópias guardadas, se existentes:
      %1 capturas acupam %2 do espaço em disco.
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>Installing </source>
        <translation>A instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Please wait.</source>
        <translation>Aguardar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Aguardar. A calcular o espaço usado em disco...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="340"/>
        <location filename="../mainwindow.cpp" line="369"/>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>O ficheiro de resultados %1 já existe. Usar outro nome de ficheiro ou eliminar o ficheiro existente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Snapshot will use the following settings:*</source>
        <translation>O MX Capturas ISO usará as seguintes definições:*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>- Snapshot directory:</source>
        <translation>- Directório de capturas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>- Kernel to be used:</source>
        <translation>- Núcleo a ser usado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>O núcleo actual não suporta o algoritmo de compressão seleccionado; editar o ficheiro de configuração e seleccionar outro algoritmo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Final chance</source>
        <translation>Última hipótese</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>O MX Capturas ISO tem agora toda a informação de que precisa para criar uma imagem ISO do sistema em uso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Demorará algum tempo a terminar, dependendo do tamanho do sistema instalado e da capacidade do computador.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>OK to start?</source>
        <translation>Iniciar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="357"/>
        <source>Shutdown computer when done.</source>
        <translation>Desligar o computador quando concluído.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Could not create working directory. </source>
        <translation>Não foi possível criar o directório de trabalho.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Could not create temporary directory. </source>
        <translation>Não foi possível criar o directório temporário.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Output</source>
        <translation>Resultado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Edit Boot Menu</source>
        <translation>Editar o Menu de Arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>O programa será suspenso agora para permitir a edição de quaisquer ficheiros no directório de trabalho. Clicar em Sim para editar o menu de arranque ou em Não para ignorar este passo e continuar a criação da imagem.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Programa para criar uma imagem CD-executável a partir do sistema em execução</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>Select Snapshot Directory</source>
        <translation>Seleccionar o directório de capturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Confirmation</source>
        <translation>Confirmação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Sair efectivamente da aplicação?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="66"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation>O programa suspenderá o processo e abrirá o menu do arranque (boot menu) no editor de texto.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation>Ferramenta para criar uma imagem &quot;CD-executável&quot; do sistema em execução</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Use CLI only</source>
        <translation>Usar apenas o Terminal</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Output directory</source>
        <translation>Directório de resultados</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>path</source>
        <translation>caminho</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Output filename</source>
        <translation>Nome do ficheiro de resultados</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>name</source>
        <translation>nome</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation>Indicar um núcleo a usar, que não o núcleo predefinido em execução; usar o formato dado por &apos;uname -r&apos;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>Or the full path: %1</source>
        <translation>Ou o caminho completo: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>version, or path</source>
        <translation>versão ou caminho</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Compression level options.</source>
        <translation>Opções de nível de compressão.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation>Usar: &quot;-Xcompression-level &lt;level&gt;&quot;, ou &quot;-Xalgorithm &lt;algorithm&gt;&quot;, ou &quot;-Xhc&quot;; ver a página de manual (man page) do mksquashfs</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>&quot;option&quot;</source>
        <translation>&quot;opção&quot;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation>Criar uma imagem mensal; adicionar o &apos;Mês&apos; ao nome da imagem ISO; ignorar o cálculo do espaço utilizado</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="90"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation>Esta opção restabelece as contas-restabelecidas (reset-accounts) e a compressão, para as predefinições; argumentos que alterem esses itens serão ignorados</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation>Não calcular checksums do ficheiro ISO resultante</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation>Opção para resolver um problema no cálculo de somas de controlo (checksums) em núcleos com correcção preempt_rt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Restablecendo as contas/senhas pré-definidas root e demo (para distribuição a outros)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation>Calcular checksums do ficheiro ISO resultante</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation>Ignorar o cálculo de espaço livre para a imagem ISO resultante</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Exclude main folders, valid choices: </source>
        <translation>Excluir as pastas principais; opções válidas: </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation>Usar a opção para cada item a excluir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>one item</source>
        <translation>um item</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Compression format, valid choices: </source>
        <translation>Formato de compressão; opções válidas: </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>format</source>
        <translation>formato</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="108"/>
        <source>Shutdown computer when done.</source>
        <translation>Desligar o computador quando concluído.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="127"/>
        <location filename="../main.cpp" line="137"/>
        <location filename="../main.cpp" line="174"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O utilizador parece ser o root; para usar este programa, sair e voltar a entrar como utilizador normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="149"/>
        <location filename="../main.cpp" line="182"/>
        <source>version:</source>
        <translation>versão: </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="156"/>
        <source>You must run this program as root.</source>
        <translation>Este programa tem que ser executado como root (administrador).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="165"/>
        <source>MX Snapshot</source>
        <translation>MX-Criar Imagem ISO</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="173"/>
        <location filename="../main.cpp" line="257"/>
        <location filename="../settings.cpp" line="221"/>
        <location filename="../settings.cpp" line="234"/>
        <location filename="../settings.cpp" line="624"/>
        <location filename="../settings.cpp" line="713"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="251"/>
        <location filename="../main.cpp" line="253"/>
        <location filename="../settings.cpp" line="229"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>O núcleo actual não suporta Squashfs. Não é possível continuar.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="87"/>
        <source>Could not create working directory. </source>
        <translation>Não foi possível criar o directório de trabalho.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="109"/>
        <source>Could not create temp directory. </source>
        <translation>Não foi possível criar o directório temporário.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="216"/>
        <source>Could not find a usable kernel</source>
        <translation>Não foi encontrado nenhum núcleo utilizável</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="342"/>
        <source>Used space on / (root): </source>
        <translation>Espaço usado em / (raiz ou root): </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="345"/>
        <source>estimated</source>
        <translation>estimado</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="356"/>
        <source>Used space on /home: </source>
        <translation>Espaço usado em /home: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="407"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Espaço livre em %1, onde está a pasta de capturas: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="411"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>O espaço livre deve ser suficiente para conter os dados comprimidos de  /   e de  /home

      Se necessário, poderá ser libertado mais espaço
      removendo capturas anteriores e cópias guardadas:
      %1 imagens acupam %2 do espaço em disco.
</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="429"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="431"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="433"/>
        <source>Downloads</source>
        <translation>Transferências</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="435"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="437"/>
        <source>Networks</source>
        <translation>Redes</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="439"/>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="443"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="618"/>
        <location filename="../settings.cpp" line="707"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>O ficheiro de resultados %1 já existe. Usar outro nome de ficheiro ou eliminar o ficheiro existente.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="120"/>
        <source>Interrupted or failed to complete</source>
        <translation>Interrupção ou falha no processo</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="87"/>
        <source>Cleaning...</source>
        <translation>A limpar...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="111"/>
        <location filename="../work.cpp" line="119"/>
        <location filename="../work.cpp" line="281"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="150"/>
        <location filename="../work.cpp" line="232"/>
        <location filename="../work.cpp" line="255"/>
        <location filename="../work.cpp" line="300"/>
        <location filename="../work.cpp" line="358"/>
        <location filename="../work.cpp" line="423"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="151"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation>Disco de destino sem espaço suficiente; são necessários pelos menos %1</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="154"/>
        <source>You have %1 free space on %2</source>
        <translation>Há %1 de espaço livre em %2</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="156"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation>Havendo espaço livre suficiente, voltar a executar o programa com a opção -o/--override-size</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="179"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>A copiar o sistema de ficheiros para a nova imagem iso...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="191"/>
        <source>Could not create temp directory. </source>
        <translation>Não foi possível criar o directório &apos;temp&apos;.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="229"/>
        <source>Squashing filesystem...</source>
        <translation>A comprimir o sistema de ficheiros...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="233"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation>Não foi possível criar o ficheiro linuxfs; verificar se há espaço suficiente na partição de destino.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="252"/>
        <source>Creating CD/DVD image file...</source>
        <translation>A criar o ficheiro de imagem de CD/DVD...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="256"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>Não foi possível criar o ficheiro ISO; verificar se há espaço suficiente na partição de destino.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="263"/>
        <source>Making hybrid iso</source>
        <translation>A criar iso híbrida</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="286"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="287"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation>Captura efectuada com êxito!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="288"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>A captura demorou %1 a ser efectuada.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="289"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>Obrigado por usar o MX Capturas ISO. Executar de seguida o MX Criar USB-executável!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="297"/>
        <source>Installing </source>
        <translation>A instalar</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="300"/>
        <source>Could not install </source>
        <translation>Não foi instalado</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="310"/>
        <source>Calculating checksum...</source>
        <translation>Calculando a soma de controlo (checksum)...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="346"/>
        <source>Building new initrd...</source>
        <translation>A criar novo initrd...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="359"/>
        <source>Could not find %1 file, cannot continue</source>
        <translation>Ficheiro %1 não encontrado; impossível continuar</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="424"/>
        <source>Could not create working directory. </source>
        <translation>Não foi possível criar o directório de trabalho.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="570"/>
        <source>Calculating total size of excluded files...</source>
        <translation>A calcular o tamanho total dos ficheiros excluídos...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="581"/>
        <source>Calculating size of root...</source>
        <translation>A calcular o tamanho da raíz (root)...</translation>
    </message>
</context>
</TS>
